==> mobiusft-1.6.tar.bz2: mobiusft-1.6/src/mobius/crypt/hash_sha1.h <==
#ifndef MOBIUS_CRYPT_HASH_SHA1_H
#define MOBIUS_CRYPT_HASH_SHA1_H

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/crypt/hash_block.h>

namespace mobius
{
namespace crypt
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief SHA-1 hash function implementation
//! \author Eduardo Aguiar
//! \see http://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.180-4.pdf
//! \see RFC 3174
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class hash_sha1 : public hash_block
{
public:
  hash_sha1 () noexcept;

private:
  void _update_block (const mobius::bytearray&) noexcept final;
  void _reset () noexcept final;
  const mobius::bytearray _evaluate (const mobius::bytearray&) final;

  std::uint32_t a_;
  std::uint32_t b_;
  std::uint32_t c_;
  std::uint32_t d_;
  std::uint32_t e_;
  std::uint64_t size_;
};

} // namespace crypt
} // namespace mobius

#endif

==> mobiusft-1.9.tar.bz2: mobiusft-1.9/src/mobius/crypt/hash_sha1.h <==
#ifndef MOBIUS_CRYPT_HASH_SHA1_H
#define MOBIUS_CRYPT_HASH_SHA1_H

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/crypt/hash_block.h>

namespace mobius
{
namespace crypt
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief SHA-1 hash function implementation
//! \author Eduardo Aguiar
//! \see http://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.180-4.pdf
//! \see RFC 3174
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class hash_sha1 : public hash_block
{
public:
  hash_sha1 () noexcept;

private:
  void _update_block (const mobius::bytearray&) noexcept final;
  void _reset () noexcept final;
  mobius::bytearray _evaluate (const mobius::bytearray&) final;

  std::uint32_t a_;
  std::uint32_t b_;
  std::uint32_t c_;
  std::uint32_t d_;
  std::uint32_t e_;
  std::uint64_t size_;
};

} // namespace crypt
} // namespace mobius

#endif
